"""
This module handles document loading functionalities for the ScrapeGraphAI application.
"""

from .chromium import ChromiumLoader
from .browser_base import browser_base_fetch
from .scrape_do import scrape_do_fetch
