"""
This module contains the model definitions used in the ScrapeGraphAI application.
"""
from .openai_itt import OpenAIImageToText
from .openai_tts import OpenAITextToSpeech
from .deepseek import DeepSeek
from .oneapi import OneApi
